"""This package provides a client class that serves as wrapper for operations that 
you can perform with the API of the visual analytics tool by Berlin United for the Robocup SPL"""


__version__ = "0.6.3"

__pdoc__ = {
    'core': False,  # Excludes the entire module/folder
}